@@ -300,6 +300,13 @@ find_varname(Var, [_|T], Name) :-
 %   This predicate calls the multifile predicate unify_clause_hook/5
 %   with the same arguments to support user extensions.
 %
+%   @arg Module is the source module that   was active when loading this
+%   clause,  which  is  the  same  as  prolog_load_context/2  using  the
+%   `module` context. If this cannot be established  it is the module to
+%   which the clause itself is associated.   The argument may be used to
+%   determine whether or not a specific user transformation is in scope.
+%   See also term_expansion/2,4 and goal_expansion/2,4.
+%
 %   @tbd    This really must be  more   flexible,  dealing with much
 %           more complex source-translations,  falling   back  to  a
 %           heuristic method locating as much as possible.
@@ -402,7 +409,10 @@ ci_expand(Read, Compiled, Module, TermPos0, TermPos) :-
                 set_prolog_flag(xref, OldXRef)
               )),
           E,
-          expand_failed(E, Read)).
+          expand_failed(E, Read)),
+    compound(TermPos),                  % make sure somthing is filled.
+    arg(1, TermPos, A1), nonvar(A1),
+    arg(2, TermPos, A2), nonvar(A2).
 
 set_xref_flag(Value) :-
     current_prolog_flag(xref, Value),
@@ -495,9 +505,11 @@ ubody(B, C, _, P, P) :-
 ubody(X0, X, M, parentheses_term_position(_, _, P0), P) :-
     !,
     ubody(X0, X, M, P0, P).
-ubody(X, call(X), _,                    % X = call(X)
+ubody(X, Y, _,                    % X = call(X)
       Pos,
       term_position(From, To, From, To, [Pos])) :-
+    nonvar(Y),
+    Y = call(X),
     !,
     arg(1, Pos, From),
     arg(2, Pos, To).
