@@ -621,7 +621,15 @@ url_menu_item(URL, URL=install_from(URL)).
 %     * url(+URL)
 %     Source for downloading the package
 %     * package_directory(+Dir)
-%     Directory into which to install the package
+%     Directory into which to install the package.
+%     * global(+Boolean)
+%     If `true`, install in the XDG common application data path, making
+%     the pack accessible to everyone. If `false`, install in the XDG
+%     user application data path, making the pack accessible for the
+%     current user only.  If the option is absent, use the first
+%     existing and writable directory.  If that doesn't exist find
+%     locations where it can be created and prompt the user to do
+%     so.
 %     * interactive(+Boolean)
 %     Use default answer without asking the user if there
 %     is a default action.
@@ -663,19 +671,32 @@ pack_install(Spec, Options) :-
 pack_install_dir(PackDir, Options) :-
     option(package_directory(PackDir), Options),
     !.
-pack_install_dir(PackDir, _Options) :-          % TBD: global/user?
-    absolute_file_name(pack(.), PackDir,
+pack_install_dir(PackDir, Options) :-
+    base_alias(Alias, Options),
+    absolute_file_name(Alias, PackDir,
                        [ file_type(directory),
                          access(write),
                          file_errors(fail)
                        ]),
     !.
-pack_install_dir(PackDir, Options) :-           % TBD: global/user?
+pack_install_dir(PackDir, Options) :-
     pack_create_install_dir(PackDir, Options).
 
+base_alias(Alias, Options) :-
+    option(global(true), Options),
+    !,
+    Alias = common_app_data(pack).
+base_alias(Alias, Options) :-
+    option(global(false), Options),
+    !,
+    Alias = user_app_data(pack).
+base_alias(Alias, _Options) :-
+    Alias = pack('.').
+
 pack_create_install_dir(PackDir, Options) :-
+    base_alias(Alias, Options),
     findall(Candidate = create_dir(Candidate),
-            ( absolute_file_name(pack(.), Candidate, [solutions(all)]),
+            ( absolute_file_name(Alias, Candidate, [solutions(all)]),
               \+ exists_file(Candidate),
               \+ exists_directory(Candidate),
               file_directory_name(Candidate, Super),
